summaryrefslogtreecommitdiff
path: root/src/mongo/db/commands/dbcommands_d.cpp
diff options
context:
space:
mode:
authorHugh Tong <hugh.tong@mongodb.com>2022-05-09 16:00:06 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-05-09 21:31:49 +0000
commit6989f87e400acff7e668ba4472d4f91adf938683 (patch)
tree276ba283e6ef6f0506b940f2dab2b6f1f71371a6 /src/mongo/db/commands/dbcommands_d.cpp
parent32e2e0d1385f6e47f829ff70b9fce95b3873a54f (diff)
downloadmongo-6989f87e400acff7e668ba4472d4f91adf938683.tar.gz
SERVER-64609 Rename instances of TenantDatabaseName to DatabaseName
Diffstat (limited to 'src/mongo/db/commands/dbcommands_d.cpp')
-rw-r--r--src/mongo/db/commands/dbcommands_d.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/commands/dbcommands_d.cpp b/src/mongo/db/commands/dbcommands_d.cpp
index 7110bce5edb..51f03ce67ba 100644
--- a/src/mongo/db/commands/dbcommands_d.cpp
+++ b/src/mongo/db/commands/dbcommands_d.cpp
@@ -180,8 +180,8 @@ protected:
// When setting the profiling level, create the database if it didn't already exist.
// When just reading the profiling level, we do not create the database.
auto databaseHolder = DatabaseHolder::get(opCtx);
- // TODO SERVER-63109 Make _setProfileSettings pass TenantDatabaseName.
- const TenantDatabaseName tenantDbName(boost::none, dbName);
+ // TODO SERVER-63109 Make _setProfileSettings pass DatabaseName.
+ const DatabaseName tenantDbName(boost::none, dbName);
db = databaseHolder->openDb(opCtx, tenantDbName);
}